@@ -1,6 +1,6 @@
 /*
 
- Copyright (C) 2011-2017 Alexis Bienvenue <paamc@passoire.fr>
+ Copyright (C) 2011-2021 Alexis Bienvenüe <paamc@passoire.fr>
 
  This file is part of Auto-Multiple-Choice
 
@@ -56,6 +56,12 @@
   #endif
 #endif
 
+#ifdef OPENCV_30
+  #define OPENCV_USE_LINETYPE cv::LINE_AA
+#else
+  #define OPENCV_USE_LINETYPE 8
+#endif
+
 #include "opencv2/imgproc/imgproc.hpp"
 #ifdef OPENCV_30
   #include "opencv2/imgcodecs/imgcodecs.hpp"
@@ -96,6 +102,8 @@ int processing_error = 0;
 #define ILLUSTR_BOX 1
 #define ILLUSTR_PIXELS 2
 
+#define OFF_CONTENT_PROP 0.1
+
 /*
 
    the following functions select, from a points sequence, four
@@ -171,7 +179,7 @@ void load_image(cv::Mat &src,char *filename,
 #endif
 			 );
     } catch (const cv::Exception& ex) {
-      printf("! LOAD : Error loading scan file in ANYCOLOR [%s]\n", filename);
+      printf("! LOAD: Error loading scan file in ANYCOLOR [%s]\n", filename);
       printf("! OpenCV error: %s\n", ex.what());
       processing_error = 3;
       return;
@@ -187,7 +195,7 @@ void load_image(cv::Mat &src,char *filename,
       cv::mixChannels(&color, 1, &src, 1, from_to, 1);
       color.release();
     } else if(color.channels() != 1) {
-      printf("! LOAD : Scan file with 2 channels [%s]\n", filename);
+      printf("! LOAD: Scan file with 2 channels [%s]\n", filename);
       processing_error = 2;
       return;
     } else {
@@ -198,7 +206,7 @@ void load_image(cv::Mat &src,char *filename,
     try {
       src = cv::imread(filename, cv::IMREAD_GRAYSCALE);
     } catch (const cv::Exception& ex) {
-      printf("! LOAD : Error loading scan file in GRAYSCALE [%s]\n", filename);
+      printf("! LOAD: Error loading scan file in GRAYSCALE [%s]\n", filename);
       printf("! OpenCV error: %s\n", ex.what());
       processing_error = 3;
       return;
@@ -342,7 +350,7 @@ void sys_22(double a,double b,double c,double d,double e,double f,
               double *x,double *y) {
   double delta = a*d - b*c;
   if(delta == 0) {
-    printf("! NONINV : Non-invertible system.\n");
+    printf("! NONINV: Non-invertible system.\n");
     return;
   }
   *x = (d*e - b*f) / delta;
@@ -363,7 +371,7 @@ void revert_transform(linear_transform *direct,
                       linear_transform *back) {
   double delta = direct->a * direct->d - direct->b * direct->c;
   if(delta == 0) {
-    printf("! NONINV : Non-invertible system.\n");
+    printf("! NONINV: Non-invertible system.\n");
     return;
   }
   back->a = direct->d / delta;
@@ -502,6 +510,7 @@ void calage(cv::Mat src, cv::Mat illustr,
             cv::Mat &dst,int view=0) {
   cv::Point coins_int[4];
   int n_cc;
+  int n_content_cc;
 
   /* computes target min and max size */
 
@@ -520,14 +529,22 @@ void calage(cv::Mat src, cv::Mat illustr,
                  1 + (int)((target_min+target_max)/2 /20),
                  1 + (int)((target_min+target_max)/2 /8));
 
+#ifdef OPENCV_21
   if(view == 2) {
     /* prepares *dst from a copy of the scan (after pre-processing). */
-    dst = cv::Mat(cv::Size(src.rows, src.cols), CV_MAKETYPE(CV_8U, 3));
+    dst = cv::Mat(cv::Size(src.cols, src.rows),
+		  CV_MAKETYPE(CV_8U, 3));
 
-    // cvConvertImage(src, *dst) is not needed anymore as 'src' and 'dst' have
-    // the same type.
-    cv::bitwise_not(dst,dst);
+    cv::cvtColor(src, dst, cv::COLOR_GRAY2RGB);
+    cv::bitwise_not(dst, dst);
   }
+  if(view == 1) {
+    /* prepares *dst as a white image with same size as the scan. */
+    dst = cv::Mat::zeros(cv::Size(src.cols, src.rows),
+			 CV_MAKETYPE(CV_8U, 3));
+  }
+#endif
+
 
   printf("Target size: %.1f ; %.1f\n", target_min, target_max);
 
@@ -538,22 +555,26 @@ void calage(cv::Mat src, cv::Mat illustr,
   vector<cv::Vec4i> hierarchy; // unused; but could be used in drawContours
   cv::findContours(src, contours, hierarchy, cv::RETR_CCOMP, cv::CHAIN_APPROX_SIMPLE);
 
-#ifdef OPENCV_21
-  if(view == 1) {
-    /* prepares *dst as a white image with same size as the scan. */
-    dst = cv::Mat::zeros(cv::Size(src.rows, src.cols), CV_MAKETYPE(src.depth(), 3));
-  }
-#endif
-
   /* 3) returns the result, and draws reports */
 
   agrege_init(src.cols, src.rows, coins_x, coins_y);
   n_cc = 0;
+  n_content_cc = 0;
 
   printf("Detected connected components:\n");
 
-  for(int i = 0; i < contours.size(); i++) {
+  for(vector<vector<cv::Point> >::size_type i = 0; i < contours.size(); i++) {
     cv::Rect rect = cv::boundingRect(cv::Mat(contours[i]));
+
+    /* count connected components that are in the content area of the
+       page (not in the margins) */
+
+    if( ! ( rect.x + rect.width <= src.cols * OFF_CONTENT_PROP ||
+            rect.x >= src.cols * (1-OFF_CONTENT_PROP) ||
+            rect.y + rect.height <= src.rows * OFF_CONTENT_PROP ||
+            rect.y >= src.rows * (1-OFF_CONTENT_PROP) ) )
+      n_content_cc ++;
+    
     /* discard the connected components that are too large or too small */
     if(rect.width <= target_max && rect.width >= target_min &&
        rect.height <= target_max && rect.height >= target_min) {
@@ -575,16 +596,16 @@ void calage(cv::Mat src, cv::Mat illustr,
           with a random color. */
         cv::Scalar color = RGB_COLOR(rand() & 255, rand() & 255, rand() & 255);
         cv::rectangle(dst, cv::Point(rect.x,rect.y), cv::Point(rect.x+rect.width,rect.y+rect.height), color);
-        cv::drawContours(dst, contours, i, color, cv::FILLED);
-      }
-#endif
+        cv::drawContours(dst, contours, i, color, 2, OPENCV_USE_LINETYPE);
+     }
      if(view==2) {
        /* draws the connected component, and the enclosing rectangle,
           in green. */
         cv::Scalar color = RGB_COLOR(60,198,127);
         cv::rectangle(dst, cv::Point(rect.x,rect.y), cv::Point(rect.x+rect.width,rect.y+rect.height), color);
-        cv::drawContours(dst, contours, i, color, cv::FILLED);
+        cv::drawContours(dst, contours, i, color, 2, OPENCV_USE_LINETYPE);
      }
+#endif
     }
   }
 
@@ -601,31 +622,35 @@ void calage(cv::Mat src, cv::Mat illustr,
       printf("Frame[%d]: %.1f ; %.1f\n", i, coins_x[i], coins_y[i]);
     }
 
-    if(view==1) {
 #ifdef OPENCV_21
+    if(view==1) {
       /* draws a rectangle to see the corner marks positions on the scan. */
       for(int i = 0; i < 4; i++) {
-        cv::line(dst, coins_int[i], coins_int[(i+1)%4], RGB_COLOR(255,255,255), 1, cv::LINE_AA);
+        cv::line(dst, coins_int[i], coins_int[(i+1)%4], RGB_COLOR(255,255,255), 1, OPENCV_USE_LINETYPE);
       }
-#endif
     }
     if(view==2) {
       /* draws a rectangle to see the corner marks positions on the scan. */
       for(int i = 0; i < 4; i++) {
-        cv::line(dst, coins_int[i], coins_int[(i+1)%4], RGB_COLOR(193,29,27), 1, cv::LINE_AA);
+        cv::line(dst, coins_int[i], coins_int[(i+1)%4], RGB_COLOR(193,29,27), 1, OPENCV_USE_LINETYPE);
       }
     }
+#endif
 
     if(illustr.data!=NULL) {
       /* draws a rectangle to see the corner marks positions on the scan. */
       for(int i = 0; i < 4; i++) {
-        cv::line(illustr, coins_int[i], coins_int[(i+1)%4], BLEU, 1, cv::LINE_AA);
+        cv::line(illustr, coins_int[i], coins_int[(i+1)%4], BLEU, 1, OPENCV_USE_LINETYPE);
       }
     }
   } else {
     /* There are less than 3 correct connected components: can't know
        where are the marks on the scan! */
-    printf("! NMARKS=%d : Not enough marks detected.\n", n_cc);
+    printf("! NMARKS=%d: Not enough corner marks detected.\n", n_cc);
+
+    if(n_content_cc == 0) {
+      printf("! MAYBE_BLANK: This page seems to be blank.\n");
+    }
   }
 }
 
@@ -687,18 +712,18 @@ int check_zooms_dir(int student, char *zooms_dir=NULL,int log=0) {
       if(errno == ENOENT) {
         if(mkdir(zooms_dir,0755) != 0) {
           ok = 0;
-          printf("! ZOOMDC : Zoom dir creation error %d : %s\n", errno, zooms_dir);
+          printf("! ZOOMDC: Zoom dir creation error [%d : %s]\n", errno, zooms_dir);
         } else {
           printf(": Zoom dir created %s\n", zooms_dir);
         }
       } else {
         ok = 0;
-        printf("! ZOOMDS : Zoom dir stat error %d : %s\n", errno, zooms_dir);
+        printf("! ZOOMDS: Zoom dir stat error [%d : %s]\n", errno, zooms_dir);
       }
     } else {
       if(!S_ISDIR(zd.st_mode)) {
         ok = 0;
-        printf("! ZOOMDP : Zoom dir is not a directory : %s\n", zooms_dir);
+        printf("! ZOOMDP: Zoom dir is not a directory [%s]\n", zooms_dir);
       }
     }
   } else {
@@ -813,7 +838,7 @@ void mesure_case(cv::Mat src, cv::Mat illustr,int illustr_mode,
     if(illustr_mode == ILLUSTR_BOX) {
       /* draws the box on the illustrated image (for zoom) */
       for(int i = 0; i < 4; i++) {
-        cv::line(illustr, coins_int[i], coins_int[(i+1)%4], BLEU, 1, cv::LINE_AA);
+        cv::line(illustr, coins_int[i], coins_int[(i+1)%4], BLEU, 1, OPENCV_USE_LINETYPE);
       }
     }
 
@@ -959,7 +984,7 @@ void mesure_case(cv::Mat src, cv::Mat illustr,int illustr_mode,
 #ifdef OPENCV_21
   if(view == 1) {
     for(int i = 0; i < 4; i++) {
-      cv::line(dst, coins_int[i], coins_int[(i+1)%4], RGB_COLOR(255,255,255), 1, cv::LINE_AA);
+      cv::line(dst, coins_int[i], coins_int[(i+1)%4], RGB_COLOR(255,255,255), 1, OPENCV_USE_LINETYPE);
     }
   }
 #endif
@@ -968,7 +993,7 @@ void mesure_case(cv::Mat src, cv::Mat illustr,int illustr_mode,
     if(illustr_mode == ILLUSTR_BOX) {
       /* draws the measuring box on the illustrated image (for zoom) */
       for(int i = 0; i < 4; i++) {
-        cv::line(illustr, coins_int[i], coins_int[(i+1)%4], ROSE, 1, cv::LINE_AA);
+        cv::line(illustr, coins_int[i], coins_int[(i+1)%4], ROSE, 1, OPENCV_USE_LINETYPE);
       }
     }
 
@@ -995,13 +1020,13 @@ void mesure_case(cv::Mat src, cv::Mat illustr,int illustr_mode,
 #endif
 				 );
 	  } catch (const cv::Exception& ex) {
-            printf("! ZOOMS : Zoom save error: %s\n", ex.what());
+            printf("! ZOOMS: Zoom save error [%s]\n", ex.what());
           }
 	  if(result)
 	    printf("ZOOM %d-%d.png\n", question, answer);
 
         } else {
-          printf("! ZOOMFN : Zoom file name error\n");
+          printf("! ZOOMFN: Zoom file name error.\n");
         }
       }
     }
@@ -1020,7 +1045,7 @@ void mesure_case(cv::Mat src, cv::Mat illustr,int illustr_mode,
 int main(int argc, char** argv)
 {
   if(! setlocale(LC_ALL, "POSIX")) {
-    printf("! LOCALE : setlocale failed\n");
+    printf("! LOCALE: setlocale failed.\n");
   }
 
   double threshold = 0.6;
@@ -1073,7 +1098,7 @@ int main(int argc, char** argv)
   // -o file : gives output file name for detected layout report image
   // -v / -P : asks for marks detection debugging image report
 
-  char c;
+  int c;
   while ((c = getopt(argc, argv, "x:y:d:i:p:m:t:c:o:vPrk")) != -1) {
     switch (c) {
     case 'x': taille_orig_x = atof(optarg); break;
@@ -1128,7 +1153,7 @@ int main(int argc, char** argv)
 	  try {
 	    illustr = cv::imread(scan_file, cv::IMREAD_COLOR);
 	  } catch (const cv::Exception& ex) {
-            printf("! LOAD : Error loading scan file in COLOR [%s]\n", scan_file);
+            printf("! LOAD: Error loading scan file in COLOR [%s]\n", scan_file);
 	    printf("! OpenCV error: %s\n", ex.what());
             processing_error = 4;
 	  }
@@ -1141,7 +1166,7 @@ int main(int argc, char** argv)
         if(processing_error == 0) {
           src_calage = src.clone();
           if(src_calage.data == NULL) {
-            printf("! LOAD : Error cloning image\n");
+            printf("! LOAD: Error cloning image.\n");
             processing_error = 5;
           }
         }
@@ -1298,14 +1323,14 @@ int main(int argc, char** argv)
         fh = src.rows / 50.0;
         textpos.x = 10;
         textpos.y = (int)(1.6 * fh);
-        cv::putText(illustr, text, textpos, cv::FONT_HERSHEY_PLAIN, fh/14, BLEU, 1+(int)(fh/20), cv::LINE_AA);
+        cv::putText(illustr, text, textpos, cv::FONT_HERSHEY_PLAIN, fh/14, BLEU, 1+(int)(fh/20), OPENCV_USE_LINETYPE);
       } else {
         printf(": %s\n", commande);
-        printf("! SYNERR : Syntax error\n");
+        printf("! SYNERR: Syntax error.\n");
       }
 
     } else {
-      printf("! ERROR : not responding due to previous error.\n");
+      printf("! ERROR: not responding due to previous error.\n");
     }
 
     printf("__END__\n");
@@ -1335,7 +1360,7 @@ int main(int argc, char** argv)
 #endif
 		  );
     } catch (const cv::Exception& ex) {
-      printf("! LAYS : Layout image save error: %s\n", ex.what());
+      printf("! LAYS: Layout image save error [%s]\n", ex.what());
     }
   }
 
