@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2012-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,10 +20,12 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'pdflatex',
-	       'seuil'=>0.5,perfect_copy=>'',
-               ignore_red=>1,
-	       'export_full_csv'=>
-	       [{-copy=>4,-question=>'ballot1',-abc=>'BE'}],
-	      )->default_process;
+AMC::Test->new(
+    dir             => __FILE__,
+    tex_engine      => 'pdflatex',
+    seuil           => 0.5,
+    perfect_copy    => '',
+    ignore_red      => 1,
+    export_full_csv => [ { -copy => 4, -question => 'ballot1', -abc => 'BE' } ],
+)->default_process;
 
