@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2013-2016 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2013-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -18,17 +18,19 @@
 # along with Auto-Multiple-Choice.  If not, see
 # <http://www.gnu.org/licenses/>.
 
-use AMC::Test;
+require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,
-	       list=>'names.csv',n_copies=>1,
-	       list_key=>'id',code=>'<preassoc>',
-	       check_assoc=>{2=>'002'},
-	       perfect_copy=>[],
-	       export_full_csv=>[
-				 {-copy=>2,-question=>'bq1',-abc=>'B'},
-				 {-copy=>2,-question=>'bq2',-abc=>'0B'},
-				],
-	      )
-  ->default_process;
+AMC::Test->new(
+    dir             => __FILE__,
+    list            => 'names.csv',
+    n_copies        => 1,
+    list_key        => 'id',
+    code            => '<preassoc>',
+    check_assoc     => { 2 => '002' },
+    perfect_copy    => [],
+    export_full_csv => [
+        { -copy => 2, -question => 'bq1', -abc => 'B' },
+        { -copy => 2, -question => 'bq2', -abc => '0B' },
+    ],
+)->default_process;
 
