@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2018 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2018-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -22,26 +22,25 @@ use Data::Dumper;
 
 require "./AMC/Test.pm";
 
-my $t=AMC::Test->new('dir'=>__FILE__,
-                    );
+my $t = AMC::Test->new( dir => __FILE__, );
 
 $t->prepare();
 
-my $d=$t->get_defects();
+my $d = $t->get_defects();
 
 $t->trace("[T] Defect test: different positions");
 
-if(!$d->{DIFFERENT_POSITIONS}) {
-  $t->trace("[E] Not detected!");
-  $t->trace(Dumper($d));
-  exit(1);
+if ( !$d->{DIFFERENT_POSITIONS} ) {
+    $t->trace("[E] Not detected!");
+    $t->trace( Dumper($d) );
+    exit(1);
 }
 
-delete($d->{DIFFERENT_POSITIONS});
+delete( $d->{DIFFERENT_POSITIONS} );
 
-my @t=(keys %$d);
-if(@t) {
-  $self->trace("[E] Layout defects: ".join(', ',@t));
+my @t = ( keys %$d );
+if (@t) {
+    $self->trace( "[E] Layout defects: " . join( ', ', @t ) );
 }
 
 $t->ok;
