@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2013-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2013-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,7 +20,11 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'pdflatex',
-	       notemax=>0,check_marks=>{4=>2},perfect_copy=>'')
-  ->default_process;
+AMC::Test->new(
+    dir          => __FILE__,
+    tex_engine   => 'pdflatex',
+    notemax      => 0,
+    check_marks  => { 4 => 2 },
+    perfect_copy => ''
+)->default_process;
 
