@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2012-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,12 +20,14 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'pdflatex',
-	       'grain'=>0.1,
-	       'check_marks'=>{4=>13.3},
-	       'verdict'=>'TOTAL : %S/%M => %s/%m',
-	       'model'=>'(N).PDF',
-	       'annote'=>[3,4],'annote_files'=>['0003.PDF','0004.PDF'],
-	      )
-  ->default_process;
+AMC::Test->new(
+    dir          => __FILE__,
+    tex_engine   => 'pdflatex',
+    grain        => 0.1,
+    check_marks  => { 4 => 13.3 },
+    verdict      => 'TOTAL : %S/%M => %s/%m',
+    model        => '(N).PDF',
+    annote       => [ 3, 4 ],
+    annote_files => [ '0003.PDF', '0004.PDF' ],
+)->default_process;
 
