@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2012-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,8 +20,10 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'latex+dvipdf',
-	       'rounding'=>'n',
-	       'check_marks'=>{4=>16.84})
-  ->default_process;
+AMC::Test->new(
+    dir         => __FILE__,
+    tex_engine  => 'latex+dvipdfmx',
+    rounding    => 'n',
+    check_marks => { 4 => 16.84 }
+)->default_process;
 
