@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2018 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2018-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,6 +20,8 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'lualatex',
-	      )->default_process;
+AMC::Test->new(
+    dir        => __FILE__,
+    tex_engine => 'lualatex',
+)->default_process;
 
