@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2015-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2015-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,6 +20,9 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'xelatex',
-               n_copies=>9,pages=>[2,2,2,4,4,4,4,6,6])
-  ->default_process;
+AMC::Test->new(
+    dir        => __FILE__,
+    tex_engine => 'xelatex',
+    n_copies   => 9,
+    pages      => [ 2, 2, 2, 4, 4, 4, 4, 6, 6 ]
+)->default_process;
