@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2012 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -18,12 +18,18 @@
 # along with Auto-Multiple-Choice.  If not, see
 # <http://www.gnu.org/licenses/>.
 
-use AMC::Test;
+require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'pdflatex',
-	       'multiple'=>1,'pre_allocate'=>5,
-	       'seuil'=>0.15,perfect_copy=>'',
-	       'list_key'=>'id','code'=>'id',
-	       'check_assoc'=>{map { ("2:$_"=>sprintf("%02d",$_-4)) } (5..16)},
-	      )->default_process;
+AMC::Test->new(
+    dir          => __FILE__,
+    tex_engine   => 'pdflatex',
+    multiple     => 1,
+    pre_allocate => 5,
+    seuil        => 0.15,
+    perfect_copy => '',
+    list_key     => 'id',
+    code         => 'id',
+    check_assoc =>
+      { map { ( "2:$_" => sprintf( "%02d", $_ - 4 ) ) } ( 5 .. 16 ) },
+)->default_process;
 
