@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2012-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,8 +20,12 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'tex_engine'=>'pdflatex',
-	       'seuil'=>0.15,'grain'=>0.1,'rounding'=>'n',
-	       'check_marks'=>{2=>16.7,4=>6.7},
-	      )->default_process;
+AMC::Test->new(
+    dir         => __FILE__,
+    tex_engine  => 'pdflatex',
+    seuil       => 0.15,
+    grain       => 0.1,
+    rounding    => 'n',
+    check_marks => { 2 => 16.7, 4 => 6.7 },
+)->default_process;
 
