@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2012-2017 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2012-2021 Alexis Bienvenüe <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -20,16 +20,19 @@
 
 require "./AMC/Test.pm";
 
-AMC::Test->new('dir'=>__FILE__,'filter'=>'plain','tex_engine'=>'xelatex',
-               'seuil'=>0.15,
-	       'export_full_csv'=>[
-				  {-copy=>4,-question=>'Cam',-score=>1},
-				  {-copy=>4,-question=>'positive',-score=>2},
-				  {-copy=>4,-question=>'one',-score=>0},
-				  {-copy=>4,-question=>'eleven',-score=>1},
-				  {-copy=>4,-question=>'twelve',-score=>1},
-				  {-copy=>4,-question=>'zero',-score=>4},
-				  {-copy=>4,-question=>'way',-score=>2},
-				  ],
-	      )->default_process;
+AMC::Test->new(
+    dir             => __FILE__,
+    filter          => 'plain',
+    tex_engine      => 'xelatex',
+    seuil           => 0.15,
+    export_full_csv => [
+        { -copy => 4, -question => 'Cam',      -score => 1 },
+        { -copy => 4, -question => 'positive', -score => 2 },
+        { -copy => 4, -question => 'one',      -score => 0 },
+        { -copy => 4, -question => 'eleven',   -score => 1 },
+        { -copy => 4, -question => 'twelve',   -score => 1 },
+        { -copy => 4, -question => 'zero',     -score => 4 },
+        { -copy => 4, -question => 'way',      -score => 2 },
+    ],
+)->default_process;
 
